summaryrefslogtreecommitdiff
path: root/tests/manpage-scan.pl
diff options
context:
space:
mode:
Diffstat (limited to 'tests/manpage-scan.pl')
-rwxr-xr-xtests/manpage-scan.pl12
1 files changed, 6 insertions, 6 deletions
diff --git a/tests/manpage-scan.pl b/tests/manpage-scan.pl
index ec2e7253d..219c4a463 100755
--- a/tests/manpage-scan.pl
+++ b/tests/manpage-scan.pl
@@ -31,7 +31,7 @@
#
# src/tool_getparam.c lists all options curl can parse
# docs/curl.1 documents all command line options
# src/tool_help.c outputs all options with curl -h
# - make sure they're all in sync
#
# Output all deviances to stderr.
@@ -147,7 +147,7 @@ my %opts = (
'--no-keepalive' => 1,
'--no-progress-meter' => 1,
# pretend these options without -no exist in curl.1 and tool_help.c
'--alpn' => 6,
'--npn' => 6,
'--eprt' => 6,
@@ -157,7 +157,7 @@ my %opts = (
'--sessionid' => 6,
'--progress-meter' => 6,
# deprecated options do not need to be in tool_help.c nor curl.1
'--krb4' => 6,
'--ftp-ssl' => 6,
'--ftp-ssl-reqd' => 6,
@@ -236,7 +236,7 @@ close(R);
#########################################################################
# parse the curl code that outputs the curl -h list
-open(R, "<$root/src/tool_help.c") ||
+open(R, "<$root/src/tool_listhelp.c") ||
die "no input file";
my @toolhelp; # store all parsed parameters
while(<R>) {
@@ -286,10 +286,10 @@ foreach my $o (keys %opts) {
$missing.= " curl.1";
}
if($where & 4) {
- $exists .= " tool_help.c";
+ $exists .= " tool_listhelp.c";
}
else {
- $missing .= " tool_help.c";
+ $missing .= " tool_listhelp.c";
}
print STDERR "$o is not in$missing (but in$exists)\n";
@@ -31,7 +31,7 @@
# src/tool_getparam.c lists all options curl can parse
# docs/curl.1 documents all command line options
-# src/tool_help.c outputs all options with curl -h
+# src/tool_listhelp.c outputs all options with curl -h
# - make sure they're all in sync
#
@@ -147,7 +147,7 @@ my %opts = (
'--no-keepalive' => 1,
'--no-progress-meter' => 1,
- # pretend these options without -no exist in curl.1 and tool_help.c
+ # pretend these options without -no exist in curl.1 and tool_listhelp.c
'--alpn' => 6,
'--npn' => 6,
@@ -157,7 +157,7 @@ my %opts = (
'--sessionid' => 6,
'--progress-meter' => 6,
- # deprecated options do not need to be in tool_help.c nor curl.1
+ # deprecated options do not need to be in tool_listhelp.c nor curl.1
'--krb4' => 6,
'--ftp-ssl' => 6,